diff --git a/contravariant-extras.cabal b/contravariant-extras.cabal
--- a/contravariant-extras.cabal
+++ b/contravariant-extras.cabal
@@ -1,7 +1,7 @@
 name:
   contravariant-extras
 version:
-  0.2
+  0.3
 category:
   Control
 synopsis:
@@ -45,9 +45,9 @@
     Contravariant.Extras.TH
   exposed-modules:
     Contravariant.Extras
-    Contravariant.Extras.Contramap
+    Contravariant.Extras.Contrazip
     Contravariant.Extras.Op
-    Contravariant.Extras.Op.Contramap
+    Contravariant.Extras.Op.Contrazip
   build-depends:
     tuple-th >= 0.2.5 && < 0.3,
     template-haskell >= 2.8 && < 3,
diff --git a/library/Contravariant/Extras/Contramap.hs b/library/Contravariant/Extras/Contramap.hs
deleted file mode 100644
--- a/library/Contravariant/Extras/Contramap.hs
+++ /dev/null
@@ -1,21 +0,0 @@
--- |
--- A berserk collection of @contramap@ functions with arities of up to 42.
--- 
--- Why 42?
--- Well, naturally, because it's the answer to the ultimate question of life,
--- the universe and everything.
--- 
--- It's exported as a separate module from "Contravariant.Extras"
--- only to not pollute its documentation.
--- The "Contravariant.Extras" module still reexports this module,
--- so you can simply import that only.
--- 
-module Contravariant.Extras.Contramap where
-
-import BasePrelude
-import qualified Contravariant.Extras.TH as TH
-
-
--- Generate the @contramap@ functions:
-return (join (map (TH.divisibleContramapDecs "contramap") (reverse [2..42])))
-
diff --git a/library/Contravariant/Extras/Contrazip.hs b/library/Contravariant/Extras/Contrazip.hs
new file mode 100644
--- /dev/null
+++ b/library/Contravariant/Extras/Contrazip.hs
@@ -0,0 +1,21 @@
+-- |
+-- A berserk collection of @contrazip@ functions with arities of up to 42.
+-- 
+-- Why 42?
+-- Well, naturally, because it's the answer to the ultimate question of life,
+-- the universe and everything.
+-- 
+-- It's exported as a separate module from "Contravariant.Extras"
+-- only to not pollute its documentation.
+-- The "Contravariant.Extras" module still reexports this module,
+-- so you can simply import that only.
+-- 
+module Contravariant.Extras.Contrazip where
+
+import BasePrelude
+import qualified Contravariant.Extras.TH as TH
+
+
+-- Generate the @contrazip@ functions:
+return (join (map (TH.divisibleContrazipDecs "contrazip") (reverse [2..42])))
+
diff --git a/library/Contravariant/Extras/Op/Contramap.hs b/library/Contravariant/Extras/Op/Contramap.hs
deleted file mode 100644
--- a/library/Contravariant/Extras/Op/Contramap.hs
+++ /dev/null
@@ -1,23 +0,0 @@
--- |
--- A berserk collection of @contramap@ functions with arities of up to 42,
--- which are specialized to the 'Op' type,
--- and jump thru less hoops than their 'Divisible'-based siblings.
--- 
--- Why 42?
--- Well, naturally, because it's the answer to the ultimate question of life,
--- the universe and everything.
--- 
--- It's exported as a separate module from "Contravariant.Extras.Op"
--- only to not pollute its documentation.
--- The "Contravariant.Extras.Op" module still reexports this module,
--- so you can simply import that only.
--- 
-module Contravariant.Extras.Op.Contramap where
-
-import BasePrelude
-import qualified Contravariant.Extras.TH as TH
-
-
--- Generate the @contramap@ functions:
-return (join (map (TH.opContramapDecs "contramap") (reverse [2..42])))
-
diff --git a/library/Contravariant/Extras/Op/Contrazip.hs b/library/Contravariant/Extras/Op/Contrazip.hs
new file mode 100644
--- /dev/null
+++ b/library/Contravariant/Extras/Op/Contrazip.hs
@@ -0,0 +1,23 @@
+-- |
+-- A berserk collection of @contrazip@ functions with arities of up to 42,
+-- which are specialized to the 'Op' type,
+-- and jump thru fewer hoops than their 'Divisible'-based siblings.
+-- 
+-- Why 42?
+-- Well, naturally, because it's the answer to the ultimate question of life,
+-- the universe and everything.
+-- 
+-- It's exported as a separate module from "Contravariant.Extras.Op"
+-- only to not pollute its documentation.
+-- The "Contravariant.Extras.Op" module still reexports this module,
+-- so you can simply import that only.
+-- 
+module Contravariant.Extras.Op.Contrazip where
+
+import BasePrelude
+import qualified Contravariant.Extras.TH as TH
+
+
+-- Generate the @contrazip@ functions:
+return (join (map (TH.opContrazipDecs "contrazip") (reverse [2..42])))
+
diff --git a/library/Contravariant/Extras/TH.hs b/library/Contravariant/Extras/TH.hs
--- a/library/Contravariant/Extras/TH.hs
+++ b/library/Contravariant/Extras/TH.hs
@@ -16,8 +16,8 @@
 -- tuple3 ( Op op1 ) ( Op op2 ) ( Op op3 ) =
 --   Op $ \( v1 , v2 , v3 ) -> mconcat [ op1 v1 , op2 v2 , op3 v3 ]
 -- @
-opContramapDecs :: String -> Int -> [ Dec ]
-opContramapDecs baseName arity =
+opContrazipDecs :: String -> Int -> [ Dec ]
+opContrazipDecs baseName arity =
   [ signature , value ]
   where
     name =
@@ -122,15 +122,15 @@
 -- Generates declarations in the spirit of the following:
 -- 
 -- @
--- contramap4 :: Divisible f => f a1 -> f a2 -> f a3 -> f a4 -> f ( a1 , a2 , a3 , a4 )
--- contramap4 f1 f2 f3 f4 =
+-- contrazip4 :: Divisible f => f a1 -> f a2 -> f a3 -> f a4 -> f ( a1 , a2 , a3 , a4 )
+-- contrazip4 f1 f2 f3 f4 =
 --   divide $(TupleTH.splitTupleAt 4 1) f1 $
 --   divide $(TupleTH.splitTupleAt 3 1) f2 $
 --   divide $(TupleTH.splitTupleAt 2 1) f3 $
 --   f4
 -- @
-divisibleContramapDecs :: String -> Int -> [Dec]
-divisibleContramapDecs baseName arity =
+divisibleContrazipDecs :: String -> Int -> [Dec]
+divisibleContrazipDecs baseName arity =
   [signature, value]
   where
     name =

diff --git a/library/Contravariant/Extras.hs b/library/Contravariant/Extras.hs
--- a/library/Contravariant/Extras.hs
+++ b/library/Contravariant/Extras.hs
@@ -1,9 +1,9 @@
 module Contravariant.Extras
 (
   -- |
-  -- A berserk collection of @contramap@ functions with arities of up to 42.
-  module Contravariant.Extras.Contramap,
+  -- A berserk collection of @contrazip@ functions with arities of up to 42.
+  module Contravariant.Extras.Contrazip,
 )
 where
 
-import Contravariant.Extras.Contramap
+import Contravariant.Extras.Contrazip
diff --git a/library/Contravariant/Extras/Op.hs b/library/Contravariant/Extras/Op.hs
--- a/library/Contravariant/Extras/Op.hs
+++ b/library/Contravariant/Extras/Op.hs
@@ -3,9 +3,9 @@
 module Contravariant.Extras.Op
 (
   -- |
-  -- A berserk collection of @contramap@ functions with arities of up to 42.
-  module Contravariant.Extras.Op.Contramap,
+  -- A berserk collection of @contrazip@ functions with arities of up to 42.
+  module Contravariant.Extras.Op.Contrazip,
 )
 where
 
-import Contravariant.Extras.Op.Contramap
+import Contravariant.Extras.Op.Contrazip